pub struct GetBlockchainInfoBalance {
id: String,
chain_value: Zec<NonNegative>,
chain_value_zat: Amount<NonNegative>,
monitored: bool,
value_delta: Option<Zec<NegativeAllowed>>,
value_delta_zat: Option<Amount>,
}Expand description
A value pool’s balance in Zec and Zatoshis
Fields
id: StringName of the pool
chain_value: Zec<NonNegative>Total amount in the pool, in ZEC
chain_value_zat: Amount<NonNegative>Total amount in the pool, in zatoshis
monitored: boolWhether the value pool balance is being monitored.
value_delta: Option<Zec<NegativeAllowed>>Change to the amount in the pool produced by this block, in ZEC
value_delta_zat: Option<Amount>Change to the amount in the pool produced by this block, in zatoshis
Implementations
Sourceimpl GetBlockchainInfoBalance
Auto-generated by derive_getters::Getters.
impl GetBlockchainInfoBalance
Auto-generated by derive_getters::Getters.
Sourcepub fn chain_value(&self) -> Zec<NonNegative>
pub fn chain_value(&self) -> Zec<NonNegative>
Total amount in the pool, in ZEC
Sourcepub fn chain_value_zat(&self) -> Amount<NonNegative>
pub fn chain_value_zat(&self) -> Amount<NonNegative>
Total amount in the pool, in zatoshis
Sourcepub fn value_delta(&self) -> Option<Zec<NegativeAllowed>>
pub fn value_delta(&self) -> Option<Zec<NegativeAllowed>>
Change to the amount in the pool produced by this block, in ZEC
Sourcepub fn value_delta_zat(&self) -> Option<Amount>
pub fn value_delta_zat(&self) -> Option<Amount>
Change to the amount in the pool produced by this block, in zatoshis
Sourceimpl GetBlockchainInfoBalance
impl GetBlockchainInfoBalance
Sourcepub fn new(
id: String,
chain_value: Zec<NonNegative>,
chain_value_zat: Amount<NonNegative>,
monitored: bool,
value_delta: Option<Zec<NegativeAllowed>>,
value_delta_zat: Option<Amount>,
) -> Self
pub fn new( id: String, chain_value: Zec<NonNegative>, chain_value_zat: Amount<NonNegative>, monitored: bool, value_delta: Option<Zec<NegativeAllowed>>, value_delta_zat: Option<Amount>, ) -> Self
Constructs a new GetBlockchainInfoBalance.
Sourceimpl GetBlockchainInfoBalance
impl GetBlockchainInfoBalance
Sourcepub fn zero_pools() -> [Self; 5]
pub fn zero_pools() -> [Self; 5]
Returns a list of GetBlockchainInfoBalances converted from the default ValueBalance.
Sourcepub(crate) fn new_internal(
id: impl ToString,
amount: Amount<NonNegative>,
delta_amount: Option<Amount<NegativeAllowed>>,
) -> Self
pub(crate) fn new_internal( id: impl ToString, amount: Amount<NonNegative>, delta_amount: Option<Amount<NegativeAllowed>>, ) -> Self
Creates a new GetBlockchainInfoBalance from a pool name and its value balance
and optionally with a delta value.
Sourcepub fn transparent(
amount: Amount<NonNegative>,
delta: Option<Amount<NegativeAllowed>>,
) -> Self
pub fn transparent( amount: Amount<NonNegative>, delta: Option<Amount<NegativeAllowed>>, ) -> Self
Creates a GetBlockchainInfoBalance for the transparent pool.
Sourcepub fn sprout(
amount: Amount<NonNegative>,
delta: Option<Amount<NegativeAllowed>>,
) -> Self
pub fn sprout( amount: Amount<NonNegative>, delta: Option<Amount<NegativeAllowed>>, ) -> Self
Creates a GetBlockchainInfoBalance for the Sprout pool.
Sourcepub fn sapling(
amount: Amount<NonNegative>,
delta: Option<Amount<NegativeAllowed>>,
) -> Self
pub fn sapling( amount: Amount<NonNegative>, delta: Option<Amount<NegativeAllowed>>, ) -> Self
Creates a GetBlockchainInfoBalance for the Sapling pool.
Sourcepub fn orchard(
amount: Amount<NonNegative>,
delta: Option<Amount<NegativeAllowed>>,
) -> Self
pub fn orchard( amount: Amount<NonNegative>, delta: Option<Amount<NegativeAllowed>>, ) -> Self
Creates a GetBlockchainInfoBalance for the Orchard pool.
Sourcepub fn deferred(
amount: Amount<NonNegative>,
delta: Option<Amount<NegativeAllowed>>,
) -> Self
pub fn deferred( amount: Amount<NonNegative>, delta: Option<Amount<NegativeAllowed>>, ) -> Self
Creates a GetBlockchainInfoBalance for the Lockbox pool.
Sourcepub fn value_pools(
value_balance: ValueBalance<NonNegative>,
delta_balance: Option<ValueBalance<NegativeAllowed>>,
) -> [Self; 5]
pub fn value_pools( value_balance: ValueBalance<NonNegative>, delta_balance: Option<ValueBalance<NegativeAllowed>>, ) -> [Self; 5]
Converts a ValueBalance to a list of GetBlockchainInfoBalances.
Sourcepub fn chain_supply(value_balance: ValueBalance<NonNegative>) -> Self
pub fn chain_supply(value_balance: ValueBalance<NonNegative>) -> Self
Converts a ValueBalance to a GetBlockchainInfoBalance representing the total chain supply.