pub struct GetMiningInfoResponse {
tip_height: u32,
current_block_size: Option<usize>,
current_block_tx: Option<usize>,
networksolps: u64,
networkhashps: u64,
chain: String,
testnet: bool,
}Expand description
Response to a getmininginfo RPC request.
Fields
tip_height: u32The current tip height.
current_block_size: Option<usize>The size of the last mined block if any.
current_block_tx: Option<usize>The number of transactions in the last mined block if any.
networksolps: u64The estimated network solution rate in Sol/s.
networkhashps: u64The estimated network solution rate in Sol/s.
chain: StringCurrent network name as defined in BIP70 (main, test, regtest)
testnet: boolIf using testnet or not
Implementations
Sourceimpl GetMiningInfoResponse
Auto-generated by derive_getters::Getters.
impl GetMiningInfoResponse
Auto-generated by derive_getters::Getters.
Sourcepub fn tip_height(&self) -> u32
pub fn tip_height(&self) -> u32
The current tip height.
Sourcepub fn current_block_size(&self) -> Option<usize>
pub fn current_block_size(&self) -> Option<usize>
The size of the last mined block if any.
Sourcepub fn current_block_tx(&self) -> Option<usize>
pub fn current_block_tx(&self) -> Option<usize>
The number of transactions in the last mined block if any.
Sourcepub fn networksolps(&self) -> u64
pub fn networksolps(&self) -> u64
The estimated network solution rate in Sol/s.
Sourcepub fn networkhashps(&self) -> u64
pub fn networkhashps(&self) -> u64
The estimated network solution rate in Sol/s.