pub struct MempoolObject {
pub(crate) size: u64,
pub(crate) fee: Zec<NonNegative>,
pub(crate) modified_fee: Zec<NonNegative>,
pub(crate) time: i64,
pub(crate) height: Height,
pub(crate) descendantcount: u64,
pub(crate) descendantsize: u64,
pub(crate) descendantfees: u64,
pub(crate) depends: Vec<String>,
}Expand description
A mempool transaction details object as returned by getrawmempool in
verbose mode.
Fields
size: u64Transaction size in bytes.
fee: Zec<NonNegative>Transaction fee in zatoshi.
modified_fee: Zec<NonNegative>Transaction fee with fee deltas used for mining priority.
time: i64Local time transaction entered pool in seconds since 1 Jan 1970 GMT
height: HeightBlock height when transaction entered pool.
descendantcount: u64Number of in-mempool descendant transactions (including this one).
descendantsize: u64Size of in-mempool descendants (including this one).
descendantfees: u64Modified fees (see “modifiedfee” above) of in-mempool descendants (including this one).
depends: Vec<String>Transaction IDs of unconfirmed transactions used as inputs for this transaction.
Implementations
Sourceimpl MempoolObject
Auto-generated by derive_getters::Getters.
impl MempoolObject
Auto-generated by derive_getters::Getters.
Sourcepub fn fee(&self) -> Zec<NonNegative>
pub fn fee(&self) -> Zec<NonNegative>
Transaction fee in zatoshi.
Sourcepub fn modified_fee(&self) -> Zec<NonNegative>
pub fn modified_fee(&self) -> Zec<NonNegative>
Transaction fee with fee deltas used for mining priority.
Sourcepub fn descendantcount(&self) -> u64
pub fn descendantcount(&self) -> u64
Number of in-mempool descendant transactions (including this one).
Sourcepub fn descendantsize(&self) -> u64
pub fn descendantsize(&self) -> u64
Size of in-mempool descendants (including this one).
Sourcepub fn descendantfees(&self) -> u64
pub fn descendantfees(&self) -> u64
Modified fees (see “modifiedfee” above) of in-mempool descendants (including this one).
Sourceimpl MempoolObject
impl MempoolObject
Sourceimpl MempoolObject
impl MempoolObject
pub(crate) fn from_verified_unmined_tx( unmined_tx: &VerifiedUnminedTx, transactions: &[VerifiedUnminedTx], transaction_dependencies: &TransactionDependencies, ) -> Self