pub struct PeerInfo {
pub(crate) addr: PeerSocketAddr,
pub(crate) services: String,
pub(crate) lastrecv: u32,
pub(crate) inbound: bool,
pub(crate) banscore: u32,
pub(crate) subver: String,
pub(crate) version: u32,
pub(crate) connection_state: String,
pub(crate) pingtime: Option<f64>,
pub(crate) pingwait: Option<f64>,
}Expand description
Item of the getpeerinfo response
Fields
addr: PeerSocketAddrThe IP address and port of the peer
services: StringThe services offered, as a zero-padded 16-character hex string
lastrecv: u32The time in seconds since epoch of the last message received from this peer
inbound: boolInbound (true) or Outbound (false)
banscore: u32The ban score for misbehavior
subver: StringThe peer’s user agent string (e.g. “/Zebra:2.1.0/” or “/MagicBean:5.8.0/”)
version: u32The negotiated protocol version
connection_state: StringThe connection state (e.g. “connected”, “never_connected”, “failed”, “connecting”)
pingtime: Option<f64>The round-trip ping time in seconds.
pingwait: Option<f64>The wait time on a ping response in seconds.
Implementations
Sourceimpl PeerInfo
Auto-generated by derive_getters::Getters.
impl PeerInfo
Auto-generated by derive_getters::Getters.
Sourcepub fn addr(&self) -> PeerSocketAddr
pub fn addr(&self) -> PeerSocketAddr
The IP address and port of the peer
Sourcepub fn services(&self) -> &String
pub fn services(&self) -> &String
The services offered, as a zero-padded 16-character hex string
Sourcepub fn lastrecv(&self) -> u32
pub fn lastrecv(&self) -> u32
The time in seconds since epoch of the last message received from this peer
Sourcepub fn subver(&self) -> &String
pub fn subver(&self) -> &String
The peer’s user agent string (e.g. “/Zebra:2.1.0/” or “/MagicBean:5.8.0/”)
Sourcepub fn connection_state(&self) -> &String
pub fn connection_state(&self) -> &String
The connection state (e.g. “connected”, “never_connected”, “failed”, “connecting”)