pub struct TransactionTemplate<FeeConstraint>{
pub(crate) data: SerializedTransaction,
pub(crate) hash: Hash,
pub(crate) auth_digest: AuthDigest,
pub(crate) depends: Vec<u16>,
pub(crate) fee: Amount<FeeConstraint>,
pub(crate) sigops: u32,
pub(crate) required: bool,
}Expand description
Transaction data and fields needed to generate blocks using the getblocktemplate RPC.
Fields
data: SerializedTransactionThe hex-encoded serialized data for this transaction.
hash: HashThe transaction ID of this transaction.
auth_digest: AuthDigestThe authorizing data digest of a v5 transaction, or a placeholder for older versions.
depends: Vec<u16>The transactions in this block template that this transaction depends upon.
These are 1-based indexes in the transactions list.
Zebra’s mempool does not support transaction dependencies, so this list is always empty.
We use u16 because 2 MB blocks are limited to around 39,000 transactions.
fee: Amount<FeeConstraint>The fee for this transaction.
Non-coinbase transactions must be NonNegative.
The Coinbase transaction fee is the negative sum of the fees of the transactions in
the block, so their fee must be NegativeOrZero.
sigops: u32The number of transparent signature operations in this transaction.
required: boolIs this transaction required in the block?
Coinbase transactions are required, all other transactions are not.
Implementations
Sourceimpl<FeeConstraint> TransactionTemplate<FeeConstraint>
Auto-generated by derive_getters::Getters.
impl<FeeConstraint> TransactionTemplate<FeeConstraint>
Auto-generated by derive_getters::Getters.
Sourcepub fn data(&self) -> &SerializedTransaction
pub fn data(&self) -> &SerializedTransaction
The hex-encoded serialized data for this transaction.
Sourcepub fn auth_digest(&self) -> AuthDigest
pub fn auth_digest(&self) -> AuthDigest
The authorizing data digest of a v5 transaction, or a placeholder for older versions.
Sourcepub fn depends(&self) -> &Vec<u16>
pub fn depends(&self) -> &Vec<u16>
The transactions in this block template that this transaction depends upon.
These are 1-based indexes in the transactions list.
Zebra’s mempool does not support transaction dependencies, so this list is always empty.
We use u16 because 2 MB blocks are limited to around 39,000 transactions.
Sourcepub fn fee(&self) -> Amount<FeeConstraint>
pub fn fee(&self) -> Amount<FeeConstraint>
The fee for this transaction.
Non-coinbase transactions must be NonNegative.
The Coinbase transaction fee is the negative sum of the fees of the transactions in
the block, so their fee must be NegativeOrZero.
Sourceimpl<FeeConstraint> TransactionTemplate<FeeConstraint>
impl<FeeConstraint> TransactionTemplate<FeeConstraint>
Sourcepub fn new(
data: SerializedTransaction,
hash: Hash,
auth_digest: AuthDigest,
depends: Vec<u16>,
fee: Amount<FeeConstraint>,
sigops: u32,
required: bool,
) -> Self
pub fn new( data: SerializedTransaction, hash: Hash, auth_digest: AuthDigest, depends: Vec<u16>, fee: Amount<FeeConstraint>, sigops: u32, required: bool, ) -> Self
Constructs a new TransactionTemplate.
Sourceimpl TransactionTemplate<NegativeOrZero>
impl TransactionTemplate<NegativeOrZero>
Sourcepub fn from_coinbase(tx: &UnminedTx, miner_fee: Amount<NonNegative>) -> Self
pub fn from_coinbase(tx: &UnminedTx, miner_fee: Amount<NonNegative>) -> Self
Convert from a generated coinbase transaction into a coinbase transaction template.
miner_fee is the total miner fees for the block, excluding newly created block rewards.